/**
 * The form defines which elements are displayed to a site visitor during the registration process (RSVP or checkout).
 * It also contains customizable messages and labels.
 *
 *
 * A form is an ordered list of controls (blocks), which accept guest information into a field input.
 *
 * Each control contains one or more nested inputs. For example, `Name` control has two inputs:
 * - First Name
 * - Last Name
 *
 * By default, name and email controls are always required and are pinned to the top of the form.
 */
interface Form {
    /** Nested fields as an ordered list. */
    controls?: InputControl[];
    /**
     * Set of defined form messages displayed in the UI before, during, and after a registration flow.
     * Includes the configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
     */
    messages?: FormMessages;
}
/**
 * A block of nested fields.
 * Used to aggregate similar inputs like First Name and Last Name.
 */
interface InputControl {
    /** Field control type. */
    type?: InputControlTypeWithLiterals;
    /** Whether the control is mandatory (such as `name` & `email`). When `true`, only the label can be changed. */
    system?: boolean;
    /**
     * Deprecated: Use `id` or `_id`.
     * @deprecated
     */
    name?: string;
    /** Child inputs. */
    inputs?: Input[];
    /**
     * *Deprecated:** Use `controls.inputs.label`.
     * @deprecated
     */
    label?: string;
    /** Field controls are sorted by this value in ascending order. */
    orderIndex?: number;
    /** Unique control ID. */
    _id?: string;
    /**
     * Whether the input control is deleted.
     * @readonly
     */
    deleted?: boolean | null;
}
declare enum InputControlType {
    /** Single text value field. */
    INPUT = "INPUT",
    /** Single text value field with multiple lines. */
    TEXTAREA = "TEXTAREA",
    /** Single-choice field with predefined values. */
    DROPDOWN = "DROPDOWN",
    /** Single-choice field with predefined values. */
    RADIO = "RADIO",
    /** Multiple-choice field with predefined values. */
    CHECKBOX = "CHECKBOX",
    /** Fields for entering first and last names. */
    NAME = "NAME",
    /** Fields for additional guests and their respective names. */
    GUEST_CONTROL = "GUEST_CONTROL",
    /** Single-line address field. */
    ADDRESS_SHORT = "ADDRESS_SHORT",
    /** Full address field with multiple lines. */
    ADDRESS_FULL = "ADDRESS_FULL",
    /** Fields for entering year, month, and day. */
    DATE = "DATE"
}
/** @enumType */
type InputControlTypeWithLiterals = InputControlType | 'INPUT' | 'TEXTAREA' | 'DROPDOWN' | 'RADIO' | 'CHECKBOX' | 'NAME' | 'GUEST_CONTROL' | 'ADDRESS_SHORT' | 'ADDRESS_FULL' | 'DATE';
/** Child inputs. */
interface Input {
    /** Field name. */
    name?: string;
    /**
     * *Deprecated:** Use `controls.inputs.type.TEXT_ARRAY`.
     * @deprecated
     */
    array?: boolean;
    /** Main field label. */
    label?: string;
    /** Additional labels for multi-valued fields such as address. */
    additionalLabels?: Record<string, string>;
    /** Predefined choice options for fields, such as dropdown. */
    options?: string[];
    /** Whether field is mandatory. */
    mandatory?: boolean;
    /** Maximum number of accepted characters (relevant for text fields). */
    maxLength?: number;
    /**
     * Type which determines field format.
     * Used to validate submitted response.
     */
    type?: ValueTypeWithLiterals;
    /**
     * The maximum number of accepted values for array input.
     *
     * **Note:** Only applicable for `TEXT_ARRAY` input fields.
     */
    maxSize?: number | null;
    /**
     * Default option initially selected when an input has multiple choices.
     *
     * Defaults to first (0th) option, if not configured.
     * Currently only applicable for `type.dropdown`.
     */
    defaultOptionSelection?: OptionSelection;
    /**
     * Additional labels for multi-valued fields, such as address.
     * @readonly
     */
    labels?: Label[];
}
declare enum ValueType {
    TEXT = "TEXT",
    NUMBER = "NUMBER",
    TEXT_ARRAY = "TEXT_ARRAY",
    DATE_TIME = "DATE_TIME",
    ADDRESS = "ADDRESS"
}
/** @enumType */
type ValueTypeWithLiterals = ValueType | 'TEXT' | 'NUMBER' | 'TEXT_ARRAY' | 'DATE_TIME' | 'ADDRESS';
/**
 * Describes initially selected option when an input has multiple choices.
 * Defaults to first (0th) option if not configured.
 */
interface OptionSelection extends OptionSelectionSelectedOptionOneOf {
    /**
     * 0-based index from predefined `controls.inputs.options` which is initial selection.
     * @max 199
     */
    optionIndex?: number;
    /**
     * Placeholder hint describing expected choices, such as "Please select".
     * Considered an empty choice.
     * @maxLength 200
     */
    placeholderText?: string;
}
/** @oneof */
interface OptionSelectionSelectedOptionOneOf {
    /**
     * 0-based index from predefined `controls.inputs.options` which is initial selection.
     * @max 199
     */
    optionIndex?: number;
    /**
     * Placeholder hint describing expected choices, such as "Please select".
     * Considered an empty choice.
     * @maxLength 200
     */
    placeholderText?: string;
}
interface Label {
    /** Field name. */
    name?: string;
    /** Field label. */
    label?: string;
}
/**
 * Defines form messages shown in UI before, during, and after registration flow.
 * It enables configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
 */
interface FormMessages {
    /** RSVP form ([SDK](https://dev.wix.com/docs/sdk/backend-modules/events/rsvp-v2/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/events/rsvp-v2/introduction)) messages. */
    rsvp?: RsvpFormMessages;
    /** Checkout form messages. */
    checkout?: CheckoutFormMessages;
    /** Messages shown when event registration is closed. */
    registrationClosed?: RegistrationClosedMessages;
    /** Messages shown when event tickets are unavailable. */
    ticketsUnavailable?: TicketsUnavailableMessages;
}
interface RsvpFormMessages {
    /** Label text indicating RSVP's `status` is `"YES"`. */
    rsvpYesOption?: string;
    /** Label text indicating RSVP's `status` is `"NO"`. */
    rsvpNoOption?: string;
    /** Messages displayed when an RSVP's `status` is set to `"YES"`. */
    positiveMessages?: Positive;
    /** Messages displayed when an RSVP's `status` is set to `"WAITLIST"`, for when the event is full and a waitlist is available). */
    waitlistMessages?: Positive;
    /** Messages displayed when an RSVP's `status` is set to `"NO"`. */
    negativeMessages?: Negative;
    /** "Submit form" call-to-action label text. */
    submitActionLabel?: string;
}
/** Confirmation messages shown after registration. */
interface PositiveResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** Confirmation message text. */
    message?: string;
    /** "Add to calendar" call-to-action label text. */
    addToCalendarActionLabel?: string;
    /** "Share event" call-to-action label text. */
    shareActionLabel?: string;
}
/** Confirmation messages shown after registration. */
interface NegativeResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** "Share event" call-to-action label text. */
    shareActionLabel?: string;
}
/** Set of messages shown during registration when RSVP response is positive. */
interface Positive {
    /** Main form title for positive response. */
    title?: string;
    /** Confirmation messages shown after registration. */
    confirmation?: PositiveResponseConfirmation;
}
/** A set of messages shown during registration with negative response */
interface Negative {
    /** Main form title for negative response. */
    title?: string;
    /** Confirmation messages shown after registration. */
    confirmation?: NegativeResponseConfirmation;
}
interface CheckoutFormMessages {
    /** Main form title for response. */
    title?: string;
    /** Submit form call-to-action label text. */
    submitActionLabel?: string;
    /** Confirmation messages shown after checkout. */
    confirmation?: ResponseConfirmation;
}
/** Confirmation messages shown after checkout. */
interface ResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** Confirmation message text. */
    message?: string;
    /** "Download tickets" call-to-action label text. */
    downloadTicketsLabel?: string;
    /** "Add to calendar" call-to-action label text. */
    addToCalendarLabel?: string;
    /** "Share event" call-to-action label text. */
    shareEventLabel?: string;
}
interface RegistrationClosedMessages {
    /** Message shown when event registration is closed. */
    message?: string;
    /** "Explore other events" call-to-action label text. */
    exploreEventsActionLabel?: string;
}
interface TicketsUnavailableMessages {
    /** Message shown when event tickets are unavailable. */
    message?: string;
    /** "Explore other events" call-to-action label text. */
    exploreEventsActionLabel?: string;
}
interface FormInputControlAdded {
    /** Event ID. */
    eventId?: string;
    /** Input control. */
    inputControl?: InputControl;
}
interface FormInputControlUpdated {
    /** Event ID. */
    eventId?: string;
    /** Input control. */
    updatedInputControl?: InputControl;
}
interface FormInputControlDeleted {
    /** Event ID. */
    eventId?: string;
    /** Input control. */
    deletedInputControl?: InputControl;
}
interface GetFormRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
declare enum RequestedFields {
    UNKNOWN_REQUESTED_FIELD = "UNKNOWN_REQUESTED_FIELD",
    /** Include soft deleted input controls in the response. */
    DELETED = "DELETED"
}
interface GetFormResponse {
    /**
     * Currently published event form.
     * Published form is visible to site visitors.
     */
    form?: Form;
    /**
     * Draft event form.
     * Not available to visitors unless published.
     */
    draftForm?: Form;
}
interface AddControlRequest extends AddControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Single-choice radio button style input control. */
    radioButton?: RadioButtonControl;
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
/** @oneof */
interface AddControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Single-choice radio button style input control. */
    radioButton?: RadioButtonControl;
}
interface PhoneControl {
    /**
     * Phone input label.
     * @maxLength 100
     */
    label?: string;
    /** Whether the phone input is required. */
    mandatory?: boolean;
}
interface AddressControl {
    /** Address control labels for each input. */
    labels?: AddressControlLabels;
    /** Whether an address is multi-line (consisting of multiple fields such as country, city, postal code). When `false`, address is single-line. */
    full?: boolean;
    /** Whether the address input is required. */
    mandatory?: boolean;
}
interface AddressControlLabels {
    /**
     * Single-line address input label.
     * @maxLength 100
     */
    addressLine?: string;
    /**
     * Country input label.
     * @maxLength 100
     */
    country?: string;
    /**
     * Subdivision input label.
     * @maxLength 100
     */
    subdivision?: string;
    /**
     * City input label.
     * @maxLength 100
     */
    city?: string;
    /**
     * Postal code input label.
     * @maxLength 100
     */
    postalCode?: string;
    /**
     * Street address input label.
     * @maxLength 100
     */
    streetAddress?: string;
}
interface DateControl {
    /**
     * Input control label.
     * @maxLength 100
     */
    label?: string;
    /** Whether the date input is required. */
    mandatory?: boolean;
}
interface AdditionalGuestsControl {
    /** Additional guests control labels for each input. */
    labels?: Labels;
    /** Whether the individual guest names are required. */
    namesMandatory?: boolean;
    /**
     * Maximum number of additional guests.
     * @min 1
     * @max 10
     */
    maxGuests?: number;
}
interface Labels {
    /**
     * Input label for a single guest.
     * @maxLength 200
     */
    single?: string;
    /**
     * Input label for multiple guests.
     * @maxLength 200
     */
    multiple?: string;
}
interface DropdownControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /**
     * Predefined options guests can choose from.
     * @minSize 2
     * @maxSize 200
     * @maxLength 200
     */
    options?: string[];
    /** Whether a choice is required. */
    mandatory?: boolean;
    /**
     * Default option initially selected when an input has multiple choices.
     *
     * Defaults to first (0th) option, if not configured.
     */
    defaultOptionSelection?: OptionSelection;
}
interface RadioButtonControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /**
     * Predefined options guests can choose from.
     * @minSize 2
     * @maxSize 200
     * @maxLength 200
     */
    options?: string[];
}
interface CheckboxControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /** Whether at least one checkbox is required. */
    mandatory?: boolean;
    /**
     * Predefined options guests can choose from.
     * @minSize 1
     * @maxSize 200
     * @maxLength 200
     */
    options?: string[];
}
interface TextControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /** Whether a text input is required. */
    mandatory?: boolean;
    /**
     * Maximum number of characters allowed.
     * @max 1000
     */
    maxLength?: number;
    /** Whether the input control should allow multiple lines in text. */
    multiLine?: boolean;
    /** Whether the input control should be displayed as a comment. */
    comment?: boolean;
}
interface AddControlResponse {
    /** Generated unique input control ID. */
    _id?: string;
    /** Modified draft event form. */
    form?: Form;
}
interface UpdateControlRequest extends UpdateControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Main guest name input control. */
    name?: NameControl;
    /** Main guest email input control. */
    email?: EmailControl;
    /** Single-choice radio style input control. */
    radioButton?: RadioButtonControl;
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /** Unique input control ID. */
    _id: string;
    /** Index used to sort input controls in ascending order. */
    orderIndex?: number;
}
/** @oneof */
interface UpdateControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Main guest name input control. */
    name?: NameControl;
    /** Main guest email input control. */
    email?: EmailControl;
    /** Single-choice radio style input control. */
    radioButton?: RadioButtonControl;
}
interface NameControl {
    /** Name control labels of each input. */
    labels?: NameControlLabels;
}
interface NameControlLabels {
    /**
     * First name input label.
     * @maxLength 100
     */
    firstName?: string;
    /**
     * Last name input label .
     * @maxLength 100
     */
    lastName?: string;
}
interface EmailControl {
    /**
     * Email input label.
     * @maxLength 100
     */
    label?: string;
}
interface UpdateControlResponse {
    /** Modified draft event form. */
    form?: Form;
}
interface DeleteControlRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * Unique input control ID.
     * @maxLength 100
     */
    _id: string;
}
interface DeleteControlResponse {
    /** Modified draft event form. */
    form?: Form;
}
interface UpdateMessagesRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * Set of field paths, specifying which parts of this resource to update.
     * When fields are empty, request is interpreted as full update.
     * Behavior follows [google.protobuf.FieldMask](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask) semantics.
     */
    fields?: string[];
    /** Set of configured form messages to update. */
    messages?: FormMessages;
}
interface UpdateMessagesResponse {
    /** Modified draft event form. */
    form?: Form;
}
interface PublishDraftRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
interface PublishDraftResponse {
    /** Published event form. */
    form?: Form;
}
interface EventUpdated {
    /** Event update timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** Event location. */
    location?: Location;
    /** Event schedule configuration. */
    scheduleConfig?: ScheduleConfig;
    /** Event title. */
    title?: string;
    /**
     * Whether schedule configuration was updated.
     * @deprecated
     */
    scheduleConfigUpdated?: boolean;
    /** Updated event */
    event?: Event;
}
interface Location {
    /**
     * Location name.
     * @maxLength 50
     */
    name?: string | null;
    /** Location map coordinates. */
    coordinates?: MapCoordinates;
    /**
     * Single line address representation.
     * @maxLength 300
     */
    address?: string | null;
    /** Location type. */
    type?: LocationTypeWithLiterals;
    /**
     * Full address derived from formatted single line `address`.
     * When `full_address` is used to create or update the event, deprecated `address` and `coordinates` are ignored.
     * If provided `full_address` has empty `formatted_address` or `coordinates`, it will be auto-completed using Atlas service.
     *
     * Migration notes:
     * - `full_address.formatted_address` is equivalent to `address`.
     * - `full_address.geocode` is equivalent to `coordinates`.
     */
    fullAddress?: Address;
    /**
     * Defines event location as TBD (To Be Determined).
     * When event location is not yet defined, `name` is displayed instead of location address.
     * `coordinates`, `address`, `type` and `full_address` are not required when location is TBD.
     */
    tbd?: boolean | null;
}
interface MapCoordinates {
    /**
     * Latitude.
     * @min -90
     * @max 90
     */
    lat?: number;
    /**
     * Longitude.
     * @min -180
     * @max 180
     */
    lng?: number;
}
declare enum LocationType {
    VENUE = "VENUE",
    ONLINE = "ONLINE"
}
/** @enumType */
type LocationTypeWithLiterals = LocationType | 'VENUE' | 'ONLINE';
/** Physical address */
interface Address extends AddressStreetOneOf {
    /** a break down of the street to number and street name */
    streetAddress?: StreetAddress;
    /** Main address line (usually street and number) as free text */
    addressLine1?: string | null;
    /**
     * country code
     * @format COUNTRY
     */
    country?: string | null;
    /** subdivision (usually state or region) code according to ISO 3166-2 */
    subdivision?: string | null;
    /** city name */
    city?: string | null;
    /** zip/postal code */
    postalCode?: string | null;
    /** Free text providing more detailed address info. Usually contains Apt, Suite, Floor */
    addressLine2?: string | null;
    /** A string containing the human-readable address of this location */
    formatted?: string | null;
    /** coordinates of the physical address */
    location?: AddressLocation;
    /** country full-name */
    countryFullname?: string | null;
    /**
     * multi-level subdivisions from top to bottom
     * @maxSize 6
     */
    subdivisions?: Subdivision[];
}
/** @oneof */
interface AddressStreetOneOf {
    /** a break down of the street to number and street name */
    streetAddress?: StreetAddress;
    /** Main address line (usually street and number) as free text */
    addressLine?: string | null;
}
interface StreetAddress {
    /** street number */
    number?: string;
    /** street name */
    name?: string;
}
interface AddressLocation {
    /**
     * address latitude coordinates
     * @min -90
     * @max 90
     */
    latitude?: number | null;
    /**
     * address longitude coordinates
     * @min -180
     * @max 180
     */
    longitude?: number | null;
}
interface Subdivision {
    /** subdivision short code */
    code?: string;
    /** subdivision full-name */
    name?: string;
}
declare enum SubdivisionType {
    UNKNOWN_SUBDIVISION_TYPE = "UNKNOWN_SUBDIVISION_TYPE",
    /** State */
    ADMINISTRATIVE_AREA_LEVEL_1 = "ADMINISTRATIVE_AREA_LEVEL_1",
    /** County */
    ADMINISTRATIVE_AREA_LEVEL_2 = "ADMINISTRATIVE_AREA_LEVEL_2",
    /** City/town */
    ADMINISTRATIVE_AREA_LEVEL_3 = "ADMINISTRATIVE_AREA_LEVEL_3",
    /** Neighborhood/quarter */
    ADMINISTRATIVE_AREA_LEVEL_4 = "ADMINISTRATIVE_AREA_LEVEL_4",
    /** Street/block */
    ADMINISTRATIVE_AREA_LEVEL_5 = "ADMINISTRATIVE_AREA_LEVEL_5",
    /** ADMINISTRATIVE_AREA_LEVEL_0. Indicates the national political entity, and is typically the highest order type returned by the Geocoder. */
    COUNTRY = "COUNTRY"
}
interface ScheduleConfig {
    /**
     * Defines event as TBD (To Be Determined) schedule.
     * When event time is not yet defined, TBD message is displayed instead of event start and end times.
     * `startDate`, `endDate` and `timeZoneId` are not required when schedule is TBD.
     */
    scheduleTbd?: boolean;
    /**
     * TBD message.
     * @maxLength 100
     */
    scheduleTbdMessage?: string | null;
    /** Event start timestamp. */
    startDate?: Date | null;
    /** Event end timestamp. */
    endDate?: Date | null;
    /**
     * Event time zone ID in TZ database format, e.g., `EST`, `America/Los_Angeles`.
     * @maxLength 100
     */
    timeZoneId?: string | null;
    /** Whether end date is hidden in the formatted schedule. */
    endDateHidden?: boolean;
    /** Whether time zone is displayed in formatted schedule. */
    showTimeZone?: boolean;
    /** Event recurrences. */
    recurrences?: Recurrences;
}
interface Recurrences {
    /**
     * Event occurrences.
     * @maxSize 1000
     */
    occurrences?: Occurrence[];
    /**
     * Recurring event category ID.
     * @readonly
     */
    categoryId?: string | null;
    /**
     * Recurrence status.
     * @readonly
     */
    status?: StatusWithLiterals;
}
interface Occurrence {
    /** Event start timestamp. */
    startDate?: Date | null;
    /** Event end timestamp. */
    endDate?: Date | null;
    /**
     * Event time zone ID in TZ database format, e.g., `EST`, `America/Los_Angeles`.
     * @maxLength 100
     */
    timeZoneId?: string | null;
    /** Whether time zone is displayed in formatted schedule. */
    showTimeZone?: boolean;
}
declare enum Status {
    /** Event occurs only once. */
    ONE_TIME = "ONE_TIME",
    /** Event is recurring. */
    RECURRING = "RECURRING",
    /** Marks the next upcoming occurrence of the recurring event. */
    RECURRING_NEXT = "RECURRING_NEXT",
    /** Marks the most recent ended occurrence of the recurring event. */
    RECURRING_LAST_ENDED = "RECURRING_LAST_ENDED",
    /** Marks the most recent canceled occurrence of the recurring event. */
    RECURRING_LAST_CANCELED = "RECURRING_LAST_CANCELED"
}
/** @enumType */
type StatusWithLiterals = Status | 'ONE_TIME' | 'RECURRING' | 'RECURRING_NEXT' | 'RECURRING_LAST_ENDED' | 'RECURRING_LAST_CANCELED';
interface Event {
    /**
     * Event ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /** Event location. */
    location?: Location;
    /** Event scheduling. */
    scheduling?: Scheduling;
    /** Event title. */
    title?: string;
    /** Event description. */
    description?: string;
    /** Rich-text content that are displayed in a site's "About Event" section (HTML). */
    about?: string;
    /** Main event image. */
    mainImage?: string;
    /** Event slug URL (generated from event title). */
    slug?: string;
    /** ISO 639-1 language code of the event (used in content translations). */
    language?: string;
    /** Event creation timestamp. */
    created?: Date | null;
    /** Event modified timestamp. */
    modified?: Date | null;
    /** Event status. */
    status?: EventStatusWithLiterals;
    /** RSVP or ticketing registration details. */
    registration?: Registration;
    /** "Add to calendar" URLs. */
    calendarLinks?: CalendarLinks;
    /** Event page URL components. */
    eventPageUrl?: SiteUrl;
    /** Event registration form. */
    form?: Form;
    /** Event dashboard summary of RSVP / ticket sales. */
    dashboard?: Dashboard;
    /** Instance ID of the site where event is hosted. */
    instanceId?: string;
    /** Guest list configuration. */
    guestListConfig?: GuestListConfig;
    /**
     * Event creator user ID.
     * @maxLength 36
     */
    userId?: string;
    /** Event discussion feed. For internal use. */
    feed?: Feed;
    /** Online conferencing details. */
    onlineConferencing?: OnlineConferencing;
    /** SEO settings. */
    seoSettings?: SeoSettings;
    /** Assigned contacts label key. */
    assignedContactsLabel?: string | null;
    /** Agenda details. */
    agenda?: Agenda;
    /** Categories this event is assigned to. */
    categories?: Category[];
    /** Visual settings for event. */
    eventDisplaySettings?: EventDisplaySettings;
    /** Rich content that are displayed in a site's "About Event" section. Successor to `about` field. */
    longDescription?: RichContent;
    /**
     * Event publish timestamp.
     * @readonly
     */
    publishedDate?: Date | null;
}
interface Scheduling {
    /** Schedule configuration. */
    config?: ScheduleConfig;
    /** Formatted schedule representation. */
    formatted?: string;
    /** Formatted start date of the event (empty for TBD schedules). */
    startDateFormatted?: string;
    /** Formatted start time of the event (empty for TBD schedules). */
    startTimeFormatted?: string;
    /** Formatted end date of the event (empty for TBD schedules or when end date is hidden). */
    endDateFormatted?: string;
    /** Formatted end time of the event (empty for TBD schedules or when end date is hidden). */
    endTimeFormatted?: string;
}
declare enum EventStatus {
    /** Event is public and scheduled to start */
    SCHEDULED = "SCHEDULED",
    /** Event has started */
    STARTED = "STARTED",
    /** Event has ended */
    ENDED = "ENDED",
    /** Event was canceled */
    CANCELED = "CANCELED"
}
/** @enumType */
type EventStatusWithLiterals = EventStatus | 'SCHEDULED' | 'STARTED' | 'ENDED' | 'CANCELED';
interface Registration {
    /** Event type. */
    type?: EventTypeWithLiterals;
    /** Event registration status. */
    status?: RegistrationStatusWithLiterals;
    /** RSVP collection details. */
    rsvpCollection?: RsvpCollection;
    /** Ticketing details. */
    ticketing?: Ticketing;
    /** External registration details. */
    external?: ExternalEvent;
    /** Types of users allowed to register. */
    restrictedTo?: VisitorTypeWithLiterals;
    /** Initial event type which was set when creating an event. */
    initialType?: EventTypeWithLiterals;
}
declare enum EventType {
    /** Type not available for this request fieldset */
    NA_EVENT_TYPE = "NA_EVENT_TYPE",
    /** Registration via RSVP */
    RSVP = "RSVP",
    /** Registration via ticket purchase */
    TICKETS = "TICKETS",
    /** External registration */
    EXTERNAL = "EXTERNAL",
    /** Registration not available */
    NO_REGISTRATION = "NO_REGISTRATION"
}
/** @enumType */
type EventTypeWithLiterals = EventType | 'NA_EVENT_TYPE' | 'RSVP' | 'TICKETS' | 'EXTERNAL' | 'NO_REGISTRATION';
declare enum RegistrationStatus {
    /** Registration status is not applicable */
    NA_REGISTRATION_STATUS = "NA_REGISTRATION_STATUS",
    /** Registration to event is closed */
    CLOSED = "CLOSED",
    /** Registration to event is closed manually */
    CLOSED_MANUALLY = "CLOSED_MANUALLY",
    /** Registration is open via RSVP */
    OPEN_RSVP = "OPEN_RSVP",
    /** Registration to event waitlist is open via RSVP */
    OPEN_RSVP_WAITLIST = "OPEN_RSVP_WAITLIST",
    /** Registration is open via ticket purchase */
    OPEN_TICKETS = "OPEN_TICKETS",
    /** Registration is open via external URL */
    OPEN_EXTERNAL = "OPEN_EXTERNAL",
    /** Registration will be open via RSVP */
    SCHEDULED_RSVP = "SCHEDULED_RSVP"
}
/** @enumType */
type RegistrationStatusWithLiterals = RegistrationStatus | 'NA_REGISTRATION_STATUS' | 'CLOSED' | 'CLOSED_MANUALLY' | 'OPEN_RSVP' | 'OPEN_RSVP_WAITLIST' | 'OPEN_TICKETS' | 'OPEN_EXTERNAL' | 'SCHEDULED_RSVP';
interface RsvpCollection {
    /** RSVP collection configuration. */
    config?: RsvpCollectionConfig;
}
interface RsvpCollectionConfig {
    /** Defines the supported RSVP statuses. */
    rsvpStatusOptions?: RsvpStatusOptionsWithLiterals;
    /**
     * Total guest limit available to register to the event.
     * Additional guests per RSVP are counted towards total guests.
     */
    limit?: number | null;
    /** Whether a waitlist is opened when total guest limit is reached, allowing guests to create RSVP with WAITING RSVP status. */
    waitlist?: boolean;
    /** Registration start timestamp. */
    startDate?: Date | null;
    /** Registration end timestamp. */
    endDate?: Date | null;
}
declare enum RsvpStatusOptions {
    /** Only YES RSVP status is available for RSVP registration */
    YES_ONLY = "YES_ONLY",
    /** YES and NO RSVP status options are available for the registration */
    YES_AND_NO = "YES_AND_NO"
}
/** @enumType */
type RsvpStatusOptionsWithLiterals = RsvpStatusOptions | 'YES_ONLY' | 'YES_AND_NO';
interface Ticketing {
    /**
     * Deprecated.
     * @deprecated
     */
    lowestPrice?: string | null;
    /**
     * Deprecated.
     * @deprecated
     */
    highestPrice?: string | null;
    /** Currency used in event transactions. */
    currency?: string | null;
    /** Ticketing configuration. */
    config?: TicketingConfig;
    /**
     * Price of lowest priced ticket.
     * @readonly
     */
    lowestTicketPrice?: Money;
    /**
     * Price of highest priced ticket.
     * @readonly
     */
    highestTicketPrice?: Money;
    /**
     * Formatted price of lowest priced ticket.
     * @readonly
     */
    lowestTicketPriceFormatted?: string | null;
    /**
     * Formatted price of highest priced ticket.
     * @readonly
     */
    highestTicketPriceFormatted?: string | null;
    /**
     * Whether all tickets are sold for this event.
     * @readonly
     */
    soldOut?: boolean | null;
}
interface TicketingConfig {
    /** Whether the form must be filled out separately for each ticket. */
    guestAssignedTickets?: boolean;
    /** Tax configuration. */
    taxConfig?: TaxConfig;
    /**
     * Limit of tickets that can be purchased per order, default 20.
     * @max 50
     */
    ticketLimitPerOrder?: number;
    /**
     * Duration for which the tickets being bought are reserved.
     * @min 5
     * @max 30
     */
    reservationDurationInMinutes?: number | null;
}
interface TaxConfig {
    /** Tax application settings. */
    type?: TaxTypeWithLiterals;
    /**
     * Tax name.
     * @minLength 1
     * @maxLength 10
     */
    name?: string | null;
    /**
     * Tax rate (e.g.,`21.55`).
     * @decimalValue options { gte:0.001, lte:100, maxScale:3 }
     */
    rate?: string | null;
    /** Applies taxes for donations, default true. */
    appliesToDonations?: boolean | null;
}
declare enum TaxType {
    /** Tax is included in the ticket price. */
    INCLUDED = "INCLUDED",
    /** Tax is added to the order at the checkout. */
    ADDED = "ADDED",
    /** Tax is added to the final total at the checkout. */
    ADDED_AT_CHECKOUT = "ADDED_AT_CHECKOUT"
}
/** @enumType */
type TaxTypeWithLiterals = TaxType | 'INCLUDED' | 'ADDED' | 'ADDED_AT_CHECKOUT';
interface Money {
    /**
     * *Deprecated:** Use `value` instead.
     * @format DECIMAL_VALUE
     * @deprecated
     */
    amount?: string;
    /**
     * Three-letter currency code in [ISO-4217 alphabetic](https://en.wikipedia.org/wiki/ISO_4217#Active_codes) format.
     * @format CURRENCY
     */
    currency?: string;
    /**
     * Monetary amount. Decimal string with a period as a decimal separator (e.g., 3.99). Optionally, starts with a single (-), to indicate that the amount is negative.
     * @format DECIMAL_VALUE
     */
    value?: string | null;
}
interface ExternalEvent {
    /** External event registration URL. */
    registration?: string;
}
declare enum VisitorType {
    /** Site visitor (including member) */
    VISITOR = "VISITOR",
    /** Site member */
    MEMBER = "MEMBER",
    /** Site visitor or member */
    VISITOR_OR_MEMBER = "VISITOR_OR_MEMBER"
}
/** @enumType */
type VisitorTypeWithLiterals = VisitorType | 'VISITOR' | 'MEMBER' | 'VISITOR_OR_MEMBER';
interface CalendarLinks {
    /** "Add to Google calendar" URL. */
    google?: string;
    /** "Download ICS calendar file" URL. */
    ics?: string;
}
/** Site URL components */
interface SiteUrl {
    /**
     * Base URL. For premium sites, this will be the domain.
     * For free sites, this would be site URL (e.g `mysite.wixsite.com/mysite`)
     */
    base?: string;
    /** The path to that page - e.g `/my-events/weekly-meetup-2` */
    path?: string;
}
interface Dashboard {
    /** Guest RSVP summary. */
    rsvpSummary?: RsvpSummary;
    /**
     * Summary of revenue and tickets sold.
     * (Archived orders are not included).
     */
    ticketingSummary?: TicketingSummary;
}
interface RsvpSummary {
    /** Total number of RSVPs. */
    total?: number;
    /** Number of RSVPs with status `YES`. */
    yes?: number;
    /** Number of RSVPs with status `NO`. */
    no?: number;
    /** Number of RSVPs in waitlist. */
    waitlist?: number;
}
interface TicketingSummary {
    /** Number of tickets sold. */
    tickets?: number;
    /**
     * Total revenue, excluding fees.
     * (taxes and payment provider fees are not deducted.)
     */
    revenue?: Money;
    /** Whether currency is locked and cannot be changed (generally occurs after the first order in the specified currency has been created). */
    currencyLocked?: boolean;
    /** Number of orders placed. */
    orders?: number;
    /** Total balance of confirmed transactions. */
    totalSales?: Money;
}
interface GuestListConfig {
    /** Whether members can see other members attending the event (defaults to true). */
    publicGuestList?: boolean;
}
interface Feed {
    /** Event discussion feed token. */
    token?: string;
}
interface OnlineConferencing {
    config?: OnlineConferencingConfig;
    session?: OnlineConferencingSession;
}
interface OnlineConferencingConfig {
    /**
     * Whether online conferencing is enabled (not supported for TBD schedules).
     * When enabled, links to join conferencing are generated and provided to guests.
     */
    enabled?: boolean;
    /**
     * Conferencing provider ID.
     * @format GUID
     */
    providerId?: string | null;
    /** Conference type */
    conferenceType?: ConferenceTypeWithLiterals;
}
declare enum ConferenceType {
    /** Everyone in the meeting can publish and subscribe video and audio. */
    MEETING = "MEETING",
    /** Guests can only subscribe to video and audio. */
    WEBINAR = "WEBINAR"
}
/** @enumType */
type ConferenceTypeWithLiterals = ConferenceType | 'MEETING' | 'WEBINAR';
interface OnlineConferencingSession {
    /**
     * Link for event host to start the online conference session.
     * @readonly
     */
    hostLink?: string;
    /**
     * Link for guests to join the online conference session.
     * @readonly
     */
    guestLink?: string;
    /**
     * The password required to join online conferencing session (when relevant).
     * @readonly
     */
    password?: string | null;
    /**
     * Indicates that session was created successfully on providers side.
     * @readonly
     */
    sessionCreated?: boolean | null;
    /**
     * Unique session id
     * @readonly
     */
    sessionId?: string | null;
}
interface SeoSettings {
    /**
     * URL slug
     * @maxLength 130
     */
    slug?: string;
    /** Advanced SEO data */
    advancedSeoData?: SeoSchema;
    /**
     * Hidden from SEO Site Map
     * @readonly
     */
    hidden?: boolean | null;
}
/**
 * The SEO schema object contains data about different types of meta tags. It makes sure that the information about your page is presented properly to search engines.
 * The search engines use this information for ranking purposes, or to display snippets in the search results.
 * This data will override other sources of tags (for example patterns) and will be included in the <head> section of the HTML document, while not being displayed on the page itself.
 */
interface SeoSchema {
    /** SEO tag information. */
    tags?: Tag[];
    /** SEO general settings. */
    settings?: Settings;
}
interface Keyword {
    /** Keyword value. */
    term?: string;
    /** Whether the keyword is the main focus keyword. */
    isMain?: boolean;
    /**
     * The source that added the keyword terms to the SEO settings.
     * @maxLength 1000
     */
    origin?: string | null;
}
interface Tag {
    /**
     * SEO tag type.
     *
     *
     * Supported values: `title`, `meta`, `script`, `link`.
     */
    type?: string;
    /**
     * A `{"key": "value"}` pair object where each SEO tag property (`"name"`, `"content"`, `"rel"`, `"href"`) contains a value.
     * For example: `{"name": "description", "content": "the description itself"}`.
     */
    props?: Record<string, any> | null;
    /** SEO tag meta data. For example, `{"height": 300, "width": 240}`. */
    meta?: Record<string, any> | null;
    /** SEO tag inner content. For example, `<title> inner content </title>`. */
    children?: string;
    /** Whether the tag is a custom tag. */
    custom?: boolean;
    /** Whether the tag is disabled. */
    disabled?: boolean;
}
interface Settings {
    /**
     * Whether the Auto Redirect feature, which creates `301 redirects` on a slug change, is enabled.
     *
     *
     * Default: `false` (Auto Redirect is enabled.)
     */
    preventAutoRedirect?: boolean;
    /**
     * User-selected keyword terms for a specific page.
     * @maxSize 5
     */
    keywords?: Keyword[];
}
interface Agenda {
    /** Whether the schedule is enabled for the event. */
    enabled?: boolean;
    /**
     * Agenda page URL.
     * @readonly
     */
    pageUrl?: SiteUrl;
}
interface Category {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     *
     * `MANUAL`: Category is created manually by the user.
     * `AUTO`: Category is created automatically.
     * `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission scope is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
interface CategoryCounts {
    /** Total number of draft events assigned to the category. */
    assignedEventsCount?: number | null;
    /** Total number of published events assigned to the category. Deleted events are excluded. */
    assignedDraftEventsCount?: number | null;
}
declare enum State {
    /** Created manually by the user. */
    MANUAL = "MANUAL",
    /** Created automatically. */
    AUTO = "AUTO",
    /** Created when publishing recurring events. */
    RECURRING_EVENT = "RECURRING_EVENT",
    /** Category is hidden. */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type StateWithLiterals = State | 'MANUAL' | 'AUTO' | 'RECURRING_EVENT' | 'HIDDEN';
interface EventDisplaySettings {
    /** Whether event details button is hidden. Only available for events with no registration. */
    hideEventDetailsButton?: boolean | null;
    /** Disables event details page visibility. If event has an external registration configured visitors will be redirected from this page. */
    hideEventDetailsPage?: boolean | null;
}
interface LabellingSettings {
}
interface RichContent {
    /** Node objects representing a rich content document. */
    nodes?: Node[];
    /** Object metadata. */
    metadata?: Metadata;
    /** Global styling for header, paragraph, block quote, and code block nodes in the object. */
    documentStyle?: DocumentStyle;
}
interface Node extends NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
    /** Node type. Use `APP_EMBED` for nodes that embed content from other Wix apps. Use `EMBED` to embed content in [oEmbed](https://oembed.com/) format. */
    type?: NodeTypeWithLiterals;
    /** Node ID. */
    id?: string;
    /** A list of child nodes. */
    nodes?: Node[];
    /** Padding and background color styling for the node. */
    style?: NodeStyle;
}
/** @oneof */
interface NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
}
declare enum NodeType {
    PARAGRAPH = "PARAGRAPH",
    TEXT = "TEXT",
    HEADING = "HEADING",
    BULLETED_LIST = "BULLETED_LIST",
    ORDERED_LIST = "ORDERED_LIST",
    LIST_ITEM = "LIST_ITEM",
    BLOCKQUOTE = "BLOCKQUOTE",
    CODE_BLOCK = "CODE_BLOCK",
    VIDEO = "VIDEO",
    DIVIDER = "DIVIDER",
    FILE = "FILE",
    GALLERY = "GALLERY",
    GIF = "GIF",
    HTML = "HTML",
    IMAGE = "IMAGE",
    LINK_PREVIEW = "LINK_PREVIEW",
    /** @deprecated */
    MAP = "MAP",
    POLL = "POLL",
    APP_EMBED = "APP_EMBED",
    BUTTON = "BUTTON",
    COLLAPSIBLE_LIST = "COLLAPSIBLE_LIST",
    TABLE = "TABLE",
    EMBED = "EMBED",
    COLLAPSIBLE_ITEM = "COLLAPSIBLE_ITEM",
    COLLAPSIBLE_ITEM_TITLE = "COLLAPSIBLE_ITEM_TITLE",
    COLLAPSIBLE_ITEM_BODY = "COLLAPSIBLE_ITEM_BODY",
    TABLE_CELL = "TABLE_CELL",
    TABLE_ROW = "TABLE_ROW",
    EXTERNAL = "EXTERNAL",
    AUDIO = "AUDIO",
    CAPTION = "CAPTION",
    LAYOUT = "LAYOUT",
    LAYOUT_CELL = "LAYOUT_CELL"
}
/** @enumType */
type NodeTypeWithLiterals = NodeType | 'PARAGRAPH' | 'TEXT' | 'HEADING' | 'BULLETED_LIST' | 'ORDERED_LIST' | 'LIST_ITEM' | 'BLOCKQUOTE' | 'CODE_BLOCK' | 'VIDEO' | 'DIVIDER' | 'FILE' | 'GALLERY' | 'GIF' | 'HTML' | 'IMAGE' | 'LINK_PREVIEW' | 'MAP' | 'POLL' | 'APP_EMBED' | 'BUTTON' | 'COLLAPSIBLE_LIST' | 'TABLE' | 'EMBED' | 'COLLAPSIBLE_ITEM' | 'COLLAPSIBLE_ITEM_TITLE' | 'COLLAPSIBLE_ITEM_BODY' | 'TABLE_CELL' | 'TABLE_ROW' | 'EXTERNAL' | 'AUDIO' | 'CAPTION' | 'LAYOUT' | 'LAYOUT_CELL';
interface NodeStyle {
    /** The top padding value in pixels. */
    paddingTop?: string | null;
    /** The bottom padding value in pixels. */
    paddingBottom?: string | null;
    /** The background color as a hexadecimal value. */
    backgroundColor?: string | null;
}
interface ButtonData {
    /** Styling for the button's container. */
    containerData?: PluginContainerData;
    /** The button type. */
    type?: ButtonDataTypeWithLiterals;
    /** Styling for the button. */
    styles?: Styles;
    /** The text to display on the button. */
    text?: string | null;
    /** Button link details. */
    link?: Link;
}
interface Border {
    /**
     * Deprecated: Use `borderWidth` in `styles` instead.
     * @deprecated
     */
    width?: number | null;
    /**
     * Deprecated: Use `borderRadius` in `styles` instead.
     * @deprecated
     */
    radius?: number | null;
}
interface Colors {
    /**
     * Deprecated: Use `textColor` in `styles` instead.
     * @deprecated
     */
    text?: string | null;
    /**
     * Deprecated: Use `borderColor` in `styles` instead.
     * @deprecated
     */
    border?: string | null;
    /**
     * Deprecated: Use `backgroundColor` in `styles` instead.
     * @deprecated
     */
    background?: string | null;
}
interface PluginContainerData {
    /** The width of the node when it's displayed. */
    width?: PluginContainerDataWidth;
    /** The node's alignment within its container. */
    alignment?: PluginContainerDataAlignmentWithLiterals;
    /** Spoiler cover settings for the node. */
    spoiler?: Spoiler;
    /** The height of the node when it's displayed. */
    height?: Height;
    /** Sets whether text should wrap around this node when it's displayed. If `textWrap` is `false`, the node takes up the width of its container. Defaults to `true` for all node types except 'DIVIVDER' where it defaults to `false`. */
    textWrap?: boolean | null;
}
declare enum WidthType {
    /** Width matches the content width */
    CONTENT = "CONTENT",
    /** Small Width */
    SMALL = "SMALL",
    /** Width will match the original asset width */
    ORIGINAL = "ORIGINAL",
    /** coast-to-coast display */
    FULL_WIDTH = "FULL_WIDTH"
}
/** @enumType */
type WidthTypeWithLiterals = WidthType | 'CONTENT' | 'SMALL' | 'ORIGINAL' | 'FULL_WIDTH';
interface PluginContainerDataWidth extends PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
/** @oneof */
interface PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
declare enum PluginContainerDataAlignment {
    /** Center Alignment */
    CENTER = "CENTER",
    /** Left Alignment */
    LEFT = "LEFT",
    /** Right Alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type PluginContainerDataAlignmentWithLiterals = PluginContainerDataAlignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface Spoiler {
    /** Sets whether the spoiler cover is enabled for this node. Defaults to `false`. */
    enabled?: boolean | null;
    /** The description displayed on top of the spoiler cover. */
    description?: string | null;
    /** The text for the button used to remove the spoiler cover. */
    buttonText?: string | null;
}
interface Height {
    /** A custom height value in pixels. */
    custom?: string | null;
}
declare enum ButtonDataType {
    /** Regular link button */
    LINK = "LINK",
    /** Triggers custom action that is defined in plugin configuration by the consumer */
    ACTION = "ACTION"
}
/** @enumType */
type ButtonDataTypeWithLiterals = ButtonDataType | 'LINK' | 'ACTION';
interface Styles {
    /**
     * Deprecated: Use `borderWidth` and `borderRadius` instead.
     * @deprecated
     */
    border?: Border;
    /**
     * Deprecated: Use `textColor`, `borderColor` and `backgroundColor` instead.
     * @deprecated
     */
    colors?: Colors;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /**
     * Deprecated: Use `borderWidth` for normal/hover states instead.
     * @deprecated
     */
    borderWidthHover?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /**
     * Border color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    borderColorHover?: string | null;
    /**
     * Text color as a hexadecimal value.
     * @format COLOR_HEX
     */
    textColor?: string | null;
    /**
     * Text color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    textColorHover?: string | null;
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Background color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    backgroundColorHover?: string | null;
    /** Button size option, one of `SMALL`, `MEDIUM` or `LARGE`. Defaults to `MEDIUM`. */
    buttonSize?: string | null;
}
interface Link extends LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
    /**
     * he HTML `target` attribute value for the link. This property defines where the linked document opens as follows:
     * `SELF` - Default. Opens the linked document in the same frame as the link.
     * `BLANK` - Opens the linked document in a new browser tab or window.
     * `PARENT` - Opens the linked document in the link's parent frame.
     * `TOP` - Opens the linked document in the full body of the link's browser tab or window.
     */
    target?: TargetWithLiterals;
    /** The HTML `rel` attribute value for the link. This object specifies the relationship between the current document and the linked document. */
    rel?: Rel;
    /** A serialized object used for a custom or external link panel. */
    customData?: string | null;
}
/** @oneof */
interface LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
}
declare enum Target {
    /** Opens the linked document in the same frame as it was clicked (this is default) */
    SELF = "SELF",
    /** Opens the linked document in a new window or tab */
    BLANK = "BLANK",
    /** Opens the linked document in the parent frame */
    PARENT = "PARENT",
    /** Opens the linked document in the full body of the window */
    TOP = "TOP"
}
/** @enumType */
type TargetWithLiterals = Target | 'SELF' | 'BLANK' | 'PARENT' | 'TOP';
interface Rel {
    /** Indicates to search engine crawlers not to follow the link. Defaults to `false`. */
    nofollow?: boolean | null;
    /** Indicates to search engine crawlers that the link is a paid placement such as sponsored content or an advertisement. Defaults to `false`. */
    sponsored?: boolean | null;
    /** Indicates that this link is user-generated content and isn't necessarily trusted or endorsed by the page’s author. For example, a link in a fourm post. Defaults to `false`. */
    ugc?: boolean | null;
    /** Indicates that this link protect referral information from being passed to the target website. */
    noreferrer?: boolean | null;
}
interface CodeBlockData {
    /** Styling for the code block's text. */
    textStyle?: TextStyle;
}
interface TextStyle {
    /** Text alignment. Defaults to `AUTO`. */
    textAlignment?: TextAlignmentWithLiterals;
    /** A CSS `line-height` value for the text expressed as a ratio relative to the font size. For example, if the font size is 20px, a `lineHeight` value of `'1.5'`` results in a line height of 30px. */
    lineHeight?: string | null;
}
declare enum TextAlignment {
    /** browser default, eqivalent to `initial` */
    AUTO = "AUTO",
    /** Left align */
    LEFT = "LEFT",
    /** Right align */
    RIGHT = "RIGHT",
    /** Center align */
    CENTER = "CENTER",
    /** Text is spaced to line up its left and right edges to the left and right edges of the line box, except for the last line */
    JUSTIFY = "JUSTIFY"
}
/** @enumType */
type TextAlignmentWithLiterals = TextAlignment | 'AUTO' | 'LEFT' | 'RIGHT' | 'CENTER' | 'JUSTIFY';
interface DividerData {
    /** Styling for the divider's container. */
    containerData?: PluginContainerData;
    /** Divider line style. */
    lineStyle?: LineStyleWithLiterals;
    /** Divider width. */
    width?: WidthWithLiterals;
    /** Divider alignment. */
    alignment?: AlignmentWithLiterals;
}
declare enum LineStyle {
    /** Single Line */
    SINGLE = "SINGLE",
    /** Double Line */
    DOUBLE = "DOUBLE",
    /** Dashed Line */
    DASHED = "DASHED",
    /** Dotted Line */
    DOTTED = "DOTTED"
}
/** @enumType */
type LineStyleWithLiterals = LineStyle | 'SINGLE' | 'DOUBLE' | 'DASHED' | 'DOTTED';
declare enum Width {
    /** Large line */
    LARGE = "LARGE",
    /** Medium line */
    MEDIUM = "MEDIUM",
    /** Small line */
    SMALL = "SMALL"
}
/** @enumType */
type WidthWithLiterals = Width | 'LARGE' | 'MEDIUM' | 'SMALL';
declare enum Alignment {
    /** Center alignment */
    CENTER = "CENTER",
    /** Left alignment */
    LEFT = "LEFT",
    /** Right alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type AlignmentWithLiterals = Alignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface FileData {
    /** Styling for the file's container. */
    containerData?: PluginContainerData;
    /** The source for the file's data. */
    src?: FileSource;
    /** File name. */
    name?: string | null;
    /** File type. */
    type?: string | null;
    /**
     * Use `sizeInKb` instead.
     * @deprecated
     */
    size?: number | null;
    /** Settings for PDF files. */
    pdfSettings?: PDFSettings;
    /** File MIME type. */
    mimeType?: string | null;
    /** File path. */
    path?: string | null;
    /** File size in KB. */
    sizeInKb?: string | null;
}
declare enum ViewMode {
    /** No PDF view */
    NONE = "NONE",
    /** Full PDF view */
    FULL = "FULL",
    /** Mini PDF view */
    MINI = "MINI"
}
/** @enumType */
type ViewModeWithLiterals = ViewMode | 'NONE' | 'FULL' | 'MINI';
interface FileSource extends FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
    /** Indicates whether the file's source is private. Defaults to `false`. */
    private?: boolean | null;
}
/** @oneof */
interface FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
}
interface PDFSettings {
    /**
     * PDF view mode. One of the following:
     * `NONE` : The PDF isn't displayed.
     * `FULL` : A full page view of the PDF is displayed.
     * `MINI` : A mini view of the PDF is displayed.
     */
    viewMode?: ViewModeWithLiterals;
    /** Sets whether the PDF download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the PDF print button is disabled. Defaults to `false`. */
    disablePrint?: boolean | null;
}
interface GalleryData {
    /** Styling for the gallery's container. */
    containerData?: PluginContainerData;
    /** The items in the gallery. */
    items?: Item[];
    /** Options for defining the gallery's appearance. */
    options?: GalleryOptions;
    /** Sets whether the gallery's expand button is disabled. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Sets whether the gallery's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
}
interface Media {
    /** The source for the media's data. */
    src?: FileSource;
    /** Media width in pixels. */
    width?: number | null;
    /** Media height in pixels. */
    height?: number | null;
    /** Media duration in seconds. Only relevant for audio and video files. */
    duration?: number | null;
}
interface Image {
    /** Image file details. */
    media?: Media;
    /** Link details for images that are links. */
    link?: Link;
}
interface Video {
    /** Video file details. */
    media?: Media;
    /** Video thumbnail file details. */
    thumbnail?: Media;
}
interface Item extends ItemDataOneOf {
    /** An image item. */
    image?: Image;
    /** A video item. */
    video?: Video;
    /** Item title. */
    title?: string | null;
    /** Item's alternative text. */
    altText?: string | null;
}
/** @oneof */
interface ItemDataOneOf {
    /** An image item. */
    image?: Image;
    /** A video item. */
    video?: Video;
}
interface GalleryOptions {
    /** Gallery layout. */
    layout?: Layout;
    /** Styling for gallery items. */
    item?: ItemStyle;
    /** Styling for gallery thumbnail images. */
    thumbnails?: Thumbnails;
}
declare enum LayoutType {
    /** Collage type */
    COLLAGE = "COLLAGE",
    /** Masonry type */
    MASONRY = "MASONRY",
    /** Grid type */
    GRID = "GRID",
    /** Thumbnail type */
    THUMBNAIL = "THUMBNAIL",
    /** Slider type */
    SLIDER = "SLIDER",
    /** Slideshow type */
    SLIDESHOW = "SLIDESHOW",
    /** Panorama type */
    PANORAMA = "PANORAMA",
    /** Column type */
    COLUMN = "COLUMN",
    /** Magic type */
    MAGIC = "MAGIC",
    /** Fullsize images type */
    FULLSIZE = "FULLSIZE"
}
/** @enumType */
type LayoutTypeWithLiterals = LayoutType | 'COLLAGE' | 'MASONRY' | 'GRID' | 'THUMBNAIL' | 'SLIDER' | 'SLIDESHOW' | 'PANORAMA' | 'COLUMN' | 'MAGIC' | 'FULLSIZE';
declare enum Orientation {
    /** Rows Orientation */
    ROWS = "ROWS",
    /** Columns Orientation */
    COLUMNS = "COLUMNS"
}
/** @enumType */
type OrientationWithLiterals = Orientation | 'ROWS' | 'COLUMNS';
declare enum Crop {
    /** Crop to fill */
    FILL = "FILL",
    /** Crop to fit */
    FIT = "FIT"
}
/** @enumType */
type CropWithLiterals = Crop | 'FILL' | 'FIT';
declare enum ThumbnailsAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Right alignment */
    RIGHT = "RIGHT",
    /** Bottom alignment */
    BOTTOM = "BOTTOM",
    /** Left alignment */
    LEFT = "LEFT",
    /** No thumbnail */
    NONE = "NONE"
}
/** @enumType */
type ThumbnailsAlignmentWithLiterals = ThumbnailsAlignment | 'TOP' | 'RIGHT' | 'BOTTOM' | 'LEFT' | 'NONE';
interface Layout {
    /** Gallery layout type. */
    type?: LayoutTypeWithLiterals;
    /** Sets whether horizontal scroll is enabled. Defaults to `true` unless the layout `type` is set to `GRID` or `COLLAGE`. */
    horizontalScroll?: boolean | null;
    /** Gallery orientation. */
    orientation?: OrientationWithLiterals;
    /** The number of columns to display on full size screens. */
    numberOfColumns?: number | null;
    /** The number of columns to display on mobile screens. */
    mobileNumberOfColumns?: number | null;
}
interface ItemStyle {
    /** Desirable dimension for each item in pixels (behvaior changes according to gallery type) */
    targetSize?: number | null;
    /** Item ratio */
    ratio?: number | null;
    /** Sets how item images are cropped. */
    crop?: CropWithLiterals;
    /** The spacing between items in pixels. */
    spacing?: number | null;
}
interface Thumbnails {
    /** Thumbnail alignment. */
    placement?: ThumbnailsAlignmentWithLiterals;
    /** Spacing between thumbnails in pixels. */
    spacing?: number | null;
}
interface GIFData {
    /** Styling for the GIF's container. */
    containerData?: PluginContainerData;
    /** The source of the full size GIF. */
    original?: GIF;
    /** The source of the downsized GIF. */
    downsized?: GIF;
    /** Height in pixels. */
    height?: number;
    /** Width in pixels. */
    width?: number;
    /** Type of GIF (Sticker or NORMAL). Defaults to `NORMAL`. */
    gifType?: GIFTypeWithLiterals;
}
interface GIF {
    /**
     * GIF format URL.
     * @format WEB_URL
     */
    gif?: string | null;
    /**
     * MP4 format URL.
     * @format WEB_URL
     */
    mp4?: string | null;
    /**
     * Thumbnail URL.
     * @format WEB_URL
     */
    still?: string | null;
}
declare enum GIFType {
    NORMAL = "NORMAL",
    STICKER = "STICKER"
}
/** @enumType */
type GIFTypeWithLiterals = GIFType | 'NORMAL' | 'STICKER';
interface HeadingData {
    /** Heading level from 1-6. */
    level?: number;
    /** Styling for the heading text. */
    textStyle?: TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
}
interface HTMLData extends HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
    /** Styling for the HTML node's container. Height property is irrelevant for HTML embeds when autoHeight is set to `true`. */
    containerData?: PluginContainerData;
    /** The type of HTML code. */
    source?: SourceWithLiterals;
    /** If container height is aligned with its content height. Defaults to `true`. */
    autoHeight?: boolean | null;
}
/** @oneof */
interface HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
}
declare enum Source {
    HTML = "HTML",
    ADSENSE = "ADSENSE"
}
/** @enumType */
type SourceWithLiterals = Source | 'HTML' | 'ADSENSE';
interface ImageData {
    /** Styling for the image's container. */
    containerData?: PluginContainerData;
    /** Image file details. */
    image?: Media;
    /** Link details for images that are links. */
    link?: Link;
    /** Sets whether the image expands to full screen when clicked. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Image's alternative text. */
    altText?: string | null;
    /**
     * Deprecated: use Caption node instead.
     * @deprecated
     */
    caption?: string | null;
    /** Sets whether the image's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the image is decorative and does not need an explanation. Defaults to `false`. */
    decorative?: boolean | null;
    /** Styling for the image. */
    styles?: ImageDataStyles;
}
interface StylesBorder {
    /** Border width in pixels. */
    width?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** Border radius in pixels. */
    radius?: number | null;
}
interface ImageDataStyles {
    /** Border attributes. */
    border?: StylesBorder;
}
interface LinkPreviewData {
    /** Styling for the link preview's container. */
    containerData?: PluginContainerData;
    /** Link details. */
    link?: Link;
    /** Preview title. */
    title?: string | null;
    /** Preview thumbnail URL. */
    thumbnailUrl?: string | null;
    /** Preview description. */
    description?: string | null;
    /** The preview content as HTML. */
    html?: string | null;
    /** Styling for the link preview. */
    styles?: LinkPreviewDataStyles;
}
declare enum Position {
    /** Thumbnail positioned at the start (left in LTR layouts, right in RTL layouts) */
    START = "START",
    /** Thumbnail positioned at the end (right in LTR layouts, left in RTL layouts) */
    END = "END",
    /** Thumbnail positioned at the top */
    TOP = "TOP",
    /** Thumbnail hidden and not displayed */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type PositionWithLiterals = Position | 'START' | 'END' | 'TOP' | 'HIDDEN';
interface LinkPreviewDataStyles {
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Title color as a hexadecimal value.
     * @format COLOR_HEX
     */
    titleColor?: string | null;
    /**
     * Subtitle color as a hexadecimal value.
     * @format COLOR_HEX
     */
    subtitleColor?: string | null;
    /**
     * Link color as a hexadecimal value.
     * @format COLOR_HEX
     */
    linkColor?: string | null;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /** Position of thumbnail. Defaults to `START`. */
    thumbnailPosition?: PositionWithLiterals;
}
interface MapData {
    /** Styling for the map's container. */
    containerData?: PluginContainerData;
    /** Map settings. */
    mapSettings?: MapSettings;
}
interface MapSettings {
    /** The address to display on the map. */
    address?: string | null;
    /** Sets whether the map is draggable. */
    draggable?: boolean | null;
    /** Sets whether the location marker is visible. */
    marker?: boolean | null;
    /** Sets whether street view control is enabled. */
    streetViewControl?: boolean | null;
    /** Sets whether zoom control is enabled. */
    zoomControl?: boolean | null;
    /** Location latitude. */
    lat?: number | null;
    /** Location longitude. */
    lng?: number | null;
    /** Location name. */
    locationName?: string | null;
    /** Sets whether view mode control is enabled. */
    viewModeControl?: boolean | null;
    /** Initial zoom value. */
    initialZoom?: number | null;
    /** Map type. `HYBRID` is a combination of the `ROADMAP` and `SATELLITE` map types. */
    mapType?: MapTypeWithLiterals;
}
declare enum MapType {
    /** Roadmap map type */
    ROADMAP = "ROADMAP",
    /** Satellite map type */
    SATELITE = "SATELITE",
    /** Hybrid map type */
    HYBRID = "HYBRID",
    /** Terrain map type */
    TERRAIN = "TERRAIN"
}
/** @enumType */
type MapTypeWithLiterals = MapType | 'ROADMAP' | 'SATELITE' | 'HYBRID' | 'TERRAIN';
interface ParagraphData {
    /** Styling for the paragraph text. */
    textStyle?: TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
    /** Paragraph level */
    level?: number | null;
}
interface PollData {
    /** Styling for the poll's container. */
    containerData?: PluginContainerData;
    /** Poll data. */
    poll?: Poll;
    /** Layout settings for the poll and voting options. */
    layout?: PollDataLayout;
    /** Styling for the poll and voting options. */
    design?: Design;
}
declare enum ViewRole {
    /** Only Poll creator can view the results */
    CREATOR = "CREATOR",
    /** Anyone who voted can see the results */
    VOTERS = "VOTERS",
    /** Anyone can see the results, even if one didn't vote */
    EVERYONE = "EVERYONE"
}
/** @enumType */
type ViewRoleWithLiterals = ViewRole | 'CREATOR' | 'VOTERS' | 'EVERYONE';
declare enum VoteRole {
    /** Logged in member */
    SITE_MEMBERS = "SITE_MEMBERS",
    /** Anyone */
    ALL = "ALL"
}
/** @enumType */
type VoteRoleWithLiterals = VoteRole | 'SITE_MEMBERS' | 'ALL';
interface Permissions {
    /** Sets who can view the poll results. */
    view?: ViewRoleWithLiterals;
    /** Sets who can vote. */
    vote?: VoteRoleWithLiterals;
    /** Sets whether one voter can vote multiple times. Defaults to `false`. */
    allowMultipleVotes?: boolean | null;
}
interface Option {
    /** Option ID. */
    id?: string | null;
    /** Option title. */
    title?: string | null;
    /** The image displayed with the option. */
    image?: Media;
}
interface PollSettings {
    /** Permissions settings for voting. */
    permissions?: Permissions;
    /** Sets whether voters are displayed in the vote results. Defaults to `true`. */
    showVoters?: boolean | null;
    /** Sets whether the vote count is displayed. Defaults to `true`. */
    showVotesCount?: boolean | null;
}
declare enum PollLayoutType {
    /** List */
    LIST = "LIST",
    /** Grid */
    GRID = "GRID"
}
/** @enumType */
type PollLayoutTypeWithLiterals = PollLayoutType | 'LIST' | 'GRID';
declare enum PollLayoutDirection {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type PollLayoutDirectionWithLiterals = PollLayoutDirection | 'LTR' | 'RTL';
interface PollLayout {
    /** The layout for displaying the voting options. */
    type?: PollLayoutTypeWithLiterals;
    /** The direction of the text displayed in the voting options. Text can be displayed either right-to-left or left-to-right. */
    direction?: PollLayoutDirectionWithLiterals;
    /** Sets whether to display the main poll image. Defaults to `false`. */
    enableImage?: boolean | null;
}
interface OptionLayout {
    /** Sets whether to display option images. Defaults to `false`. */
    enableImage?: boolean | null;
}
declare enum BackgroundType {
    /** Color background type */
    COLOR = "COLOR",
    /** Image background type */
    IMAGE = "IMAGE",
    /** Gradiant background type */
    GRADIENT = "GRADIENT"
}
/** @enumType */
type BackgroundTypeWithLiterals = BackgroundType | 'COLOR' | 'IMAGE' | 'GRADIENT';
interface Gradient {
    /** The gradient angle in degrees. */
    angle?: number | null;
    /**
     * The start color as a hexademical value.
     * @format COLOR_HEX
     */
    startColor?: string | null;
    /**
     * The end color as a hexademical value.
     * @format COLOR_HEX
     */
    lastColor?: string | null;
}
interface Background extends BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
    /** Background type. For each option, include the relevant details. */
    type?: BackgroundTypeWithLiterals;
}
/** @oneof */
interface BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
}
interface PollDesign {
    /** Background styling. */
    background?: Background;
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface OptionDesign {
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface Poll {
    /** Poll ID. */
    id?: string | null;
    /** Poll title. */
    title?: string | null;
    /** Poll creator ID. */
    creatorId?: string | null;
    /** Main poll image. */
    image?: Media;
    /** Voting options. */
    options?: Option[];
    /** The poll's permissions and display settings. */
    settings?: PollSettings;
}
interface PollDataLayout {
    /** Poll layout settings. */
    poll?: PollLayout;
    /** Voting otpions layout settings. */
    options?: OptionLayout;
}
interface Design {
    /** Styling for the poll. */
    poll?: PollDesign;
    /** Styling for voting options. */
    options?: OptionDesign;
}
interface TextData {
    /** The text to apply decorations to. */
    text?: string;
    /** The decorations to apply. */
    decorations?: Decoration[];
}
/** Adds appearence changes to text */
interface Decoration extends DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
    /** The type of decoration to apply. */
    type?: DecorationTypeWithLiterals;
}
/** @oneof */
interface DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
}
declare enum DecorationType {
    BOLD = "BOLD",
    ITALIC = "ITALIC",
    UNDERLINE = "UNDERLINE",
    SPOILER = "SPOILER",
    ANCHOR = "ANCHOR",
    MENTION = "MENTION",
    LINK = "LINK",
    COLOR = "COLOR",
    FONT_SIZE = "FONT_SIZE",
    EXTERNAL = "EXTERNAL",
    STRIKETHROUGH = "STRIKETHROUGH"
}
/** @enumType */
type DecorationTypeWithLiterals = DecorationType | 'BOLD' | 'ITALIC' | 'UNDERLINE' | 'SPOILER' | 'ANCHOR' | 'MENTION' | 'LINK' | 'COLOR' | 'FONT_SIZE' | 'EXTERNAL' | 'STRIKETHROUGH';
interface AnchorData {
    /** The target node's ID. */
    anchor?: string;
}
interface ColorData {
    /** The text's background color as a hexadecimal value. */
    background?: string | null;
    /** The text's foreground color as a hexadecimal value. */
    foreground?: string | null;
}
interface LinkData {
    /** Link details. */
    link?: Link;
}
interface MentionData {
    /** The mentioned user's name. */
    name?: string;
    /** The version of the user's name that appears after the `@` character in the mention. */
    slug?: string;
    /** Mentioned user's ID. */
    id?: string | null;
}
interface FontSizeData {
    /** The units used for the font size. */
    unit?: FontTypeWithLiterals;
    /** Font size value. */
    value?: number | null;
}
declare enum FontType {
    PX = "PX",
    EM = "EM"
}
/** @enumType */
type FontTypeWithLiterals = FontType | 'PX' | 'EM';
interface SpoilerData {
    /** Spoiler ID. */
    id?: string | null;
}
interface AppEmbedData extends AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
    /** The type of Wix App content being embedded. */
    type?: AppTypeWithLiterals;
    /** The ID of the embedded content. */
    itemId?: string | null;
    /** The name of the embedded content. */
    name?: string | null;
    /**
     * Deprecated: Use `image` instead.
     * @deprecated
     */
    imageSrc?: string | null;
    /** The URL for the embedded content. */
    url?: string | null;
    /** An image for the embedded content. */
    image?: Media;
}
/** @oneof */
interface AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
}
declare enum AppType {
    PRODUCT = "PRODUCT",
    EVENT = "EVENT",
    BOOKING = "BOOKING"
}
/** @enumType */
type AppTypeWithLiterals = AppType | 'PRODUCT' | 'EVENT' | 'BOOKING';
interface BookingData {
    /** Booking duration in minutes. */
    durations?: string | null;
}
interface EventData {
    /** Event schedule. */
    scheduling?: string | null;
    /** Event location. */
    location?: string | null;
}
interface VideoData {
    /** Styling for the video's container. */
    containerData?: PluginContainerData;
    /** Video details. */
    video?: Media;
    /** Video thumbnail details. */
    thumbnail?: Media;
    /** Sets whether the video's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Video title. */
    title?: string | null;
    /** Video options. */
    options?: PlaybackOptions;
}
interface PlaybackOptions {
    /** Sets whether the media will automatically start playing. */
    autoPlay?: boolean | null;
    /** Sets whether media's will be looped. */
    playInLoop?: boolean | null;
    /** Sets whether media's controls will be shown. */
    showControls?: boolean | null;
}
interface EmbedData {
    /** Styling for the oEmbed node's container. */
    containerData?: PluginContainerData;
    /** An [oEmbed](https://www.oembed.com) object. */
    oembed?: Oembed;
    /** Origin asset source. */
    src?: string | null;
}
interface Oembed {
    /** The resource type. */
    type?: string | null;
    /** The width of the resource specified in the `url` property in pixels. */
    width?: number | null;
    /** The height of the resource specified in the `url` property in pixels. */
    height?: number | null;
    /** Resource title. */
    title?: string | null;
    /** The source URL for the resource. */
    url?: string | null;
    /** HTML for embedding a video player. The HTML should have no padding or margins. */
    html?: string | null;
    /** The name of the author or owner of the resource. */
    authorName?: string | null;
    /** The URL for the author or owner of the resource. */
    authorUrl?: string | null;
    /** The name of the resource provider. */
    providerName?: string | null;
    /** The URL for the resource provider. */
    providerUrl?: string | null;
    /** The URL for a thumbnail image for the resource. If this property is defined, `thumbnailWidth` and `thumbnailHeight` must also be defined. */
    thumbnailUrl?: string | null;
    /** The width of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailHeight` must also be defined. */
    thumbnailWidth?: string | null;
    /** The height of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailWidth`must also be defined. */
    thumbnailHeight?: string | null;
    /** The URL for an embedded viedo. */
    videoUrl?: string | null;
    /** The oEmbed version number.  This value must be `1.0`. */
    version?: string | null;
}
interface CollapsibleListData {
    /** Styling for the collapsible list's container. */
    containerData?: PluginContainerData;
    /** If `true`, only one item can be expanded at a time. Defaults to `false`. */
    expandOnlyOne?: boolean | null;
    /** Sets which items are expanded when the page loads. */
    initialExpandedItems?: InitialExpandedItemsWithLiterals;
    /** The direction of the text in the list. Either left-to-right or right-to-left. */
    direction?: DirectionWithLiterals;
    /** If `true`, The collapsible item will appear in search results as an FAQ. */
    isQapageData?: boolean | null;
}
declare enum InitialExpandedItems {
    /** First item will be expended initally */
    FIRST = "FIRST",
    /** All items will expended initally */
    ALL = "ALL",
    /** All items collapsed initally */
    NONE = "NONE"
}
/** @enumType */
type InitialExpandedItemsWithLiterals = InitialExpandedItems | 'FIRST' | 'ALL' | 'NONE';
declare enum Direction {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type DirectionWithLiterals = Direction | 'LTR' | 'RTL';
interface TableData {
    /** Styling for the table's container. */
    containerData?: PluginContainerData;
    /** The table's dimensions. */
    dimensions?: Dimensions;
    /**
     * Deprecated: Use `rowHeader` and `columnHeader` instead.
     * @deprecated
     */
    header?: boolean | null;
    /** Sets whether the table's first row is a header. Defaults to `false`. */
    rowHeader?: boolean | null;
    /** Sets whether the table's first column is a header. Defaults to `false`. */
    columnHeader?: boolean | null;
}
interface Dimensions {
    /** An array representing relative width of each column in relation to the other columns. */
    colsWidthRatio?: number[];
    /** An array representing the height of each row in pixels. */
    rowsHeight?: number[];
    /** An array representing the minimum width of each column in pixels. */
    colsMinWidth?: number[];
}
interface TableCellData {
    /** Styling for the cell's background color and text alignment. */
    cellStyle?: CellStyle;
    /** The cell's border colors. */
    borderColors?: BorderColors;
}
declare enum VerticalAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Middle alignment */
    MIDDLE = "MIDDLE",
    /** Bottom alignment */
    BOTTOM = "BOTTOM"
}
/** @enumType */
type VerticalAlignmentWithLiterals = VerticalAlignment | 'TOP' | 'MIDDLE' | 'BOTTOM';
interface CellStyle {
    /** Vertical alignment for the cell's text. */
    verticalAlignment?: VerticalAlignmentWithLiterals;
    /**
     * Cell background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
}
interface BorderColors {
    /**
     * Left border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    left?: string | null;
    /**
     * Right border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    right?: string | null;
    /**
     * Top border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    top?: string | null;
    /**
     * Bottom border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    bottom?: string | null;
}
/**
 * `NullValue` is a singleton enumeration to represent the null value for the
 * `Value` type union.
 *
 * The JSON representation for `NullValue` is JSON `null`.
 */
declare enum NullValue {
    /** Null value. */
    NULL_VALUE = "NULL_VALUE"
}
/**
 * `ListValue` is a wrapper around a repeated field of values.
 *
 * The JSON representation for `ListValue` is JSON array.
 */
interface ListValue {
    /** Repeated field of dynamically typed values. */
    values?: any[];
}
interface AudioData {
    /** Styling for the audio node's container. */
    containerData?: PluginContainerData;
    /** Audio file details. */
    audio?: Media;
    /** Sets whether the audio node's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Cover image. */
    coverImage?: Media;
    /** Track name. */
    name?: string | null;
    /** Author name. */
    authorName?: string | null;
    /** An HTML version of the audio node. */
    html?: string | null;
}
interface OrderedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
    /** List start number. */
    start?: number | null;
}
interface BulletedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
}
interface BlockquoteData {
    /** Indentation level from 1-4. */
    indentation?: number;
}
interface CaptionData {
    textStyle?: TextStyle;
}
interface LayoutCellData {
    /** Size of the cell in 12 columns grid. */
    colSpan?: number | null;
}
interface Metadata {
    /** Schema version. */
    version?: number;
    /**
     * When the object was created.
     * @readonly
     * @deprecated
     */
    createdTimestamp?: Date | null;
    /**
     * When the object was most recently updated.
     * @deprecated
     */
    updatedTimestamp?: Date | null;
    /** Object ID. */
    _id?: string | null;
}
interface DocumentStyle {
    /** Styling for H1 nodes. */
    headerOne?: TextNodeStyle;
    /** Styling for H2 nodes. */
    headerTwo?: TextNodeStyle;
    /** Styling for H3 nodes. */
    headerThree?: TextNodeStyle;
    /** Styling for H4 nodes. */
    headerFour?: TextNodeStyle;
    /** Styling for H5 nodes. */
    headerFive?: TextNodeStyle;
    /** Styling for H6 nodes. */
    headerSix?: TextNodeStyle;
    /** Styling for paragraph nodes. */
    paragraph?: TextNodeStyle;
    /** Styling for block quote nodes. */
    blockquote?: TextNodeStyle;
    /** Styling for code block nodes. */
    codeBlock?: TextNodeStyle;
}
interface TextNodeStyle {
    /** The decorations to apply to the node. */
    decorations?: Decoration[];
    /** Padding and background color for the node. */
    nodeStyle?: NodeStyle;
    /** Line height for text in the node. */
    lineHeight?: string | null;
}
interface Badge {
    /** Badge type. */
    type?: TypeWithLiterals;
    /**
     * Badge text.
     * @maxLength 50
     */
    text?: string | null;
}
declare enum Type {
    /** Unknown badge type. */
    UNKNOWN_BADGE_TYPE = "UNKNOWN_BADGE_TYPE",
    /** 1st priority badge type. */
    FIRST_PRIORITY = "FIRST_PRIORITY",
    /** 2nd priority badge type. */
    SECOND_PRIORITY = "SECOND_PRIORITY",
    /** 3rd priority badge type. */
    THIRD_PRIORITY = "THIRD_PRIORITY"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN_BADGE_TYPE' | 'FIRST_PRIORITY' | 'SECOND_PRIORITY' | 'THIRD_PRIORITY';
interface DiscardDraftRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
interface DiscardDraftResponse {
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface FormEventUpdatedEnvelope {
    data: EventUpdated;
    metadata: BaseEventMetadata;
}
interface AddControlOptions extends AddControlOptionsControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Single-choice radio button style input control. */
    radioButton?: RadioButtonControl;
}
/** @oneof */
interface AddControlOptionsControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Single-choice radio button style input control. */
    radioButton?: RadioButtonControl;
}
interface UpdateControlIdentifiers extends UpdateControlIdentifiersControlOneOf {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /** Unique input control ID. */
    _id: string;
}
/** @oneof */
interface UpdateControlIdentifiersControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Main guest name input control. */
    name?: NameControl;
    /** Main guest email input control. */
    email?: EmailControl;
    /** Single-choice radio style input control. */
    radioButton?: RadioButtonControl;
}
interface UpdateControlOptions extends UpdateControlOptionsControlOneOf {
    /** Index used to sort input controls in ascending order. */
    orderIndex?: number;
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Main guest name input control. */
    name?: NameControl;
    /** Main guest email input control. */
    email?: EmailControl;
    /** Single-choice radio style input control. */
    radioButton?: RadioButtonControl;
}
/** @oneof */
interface UpdateControlOptionsControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Main guest name input control. */
    name?: NameControl;
    /** Main guest email input control. */
    email?: EmailControl;
    /** Single-choice radio style input control. */
    radioButton?: RadioButtonControl;
}
interface DeleteControlIdentifiers {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * Unique input control ID.
     * @maxLength 100
     */
    _id: string;
}
interface UpdateMessagesOptions {
    /**
     * Set of field paths, specifying which parts of this resource to update.
     * When fields are empty, request is interpreted as full update.
     * Behavior follows [google.protobuf.FieldMask](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask) semantics.
     */
    fields?: string[];
    /** Set of configured form messages to update. */
    messages?: FormMessages;
}

export { Direction as $, type AddControlOptions as A, ButtonDataType as B, ConferenceType as C, type DeleteControlIdentifiers as D, EventStatus as E, type Form as F, GIFType as G, VoteRole as H, InputControlType as I, PollLayoutType as J, PollLayoutDirection as K, LocationType as L, MapType as M, NodeType as N, Orientation as O, type PublishDraftResponse as P, BackgroundType as Q, RequestedFields as R, SubdivisionType as S, TaxType as T, type UpdateControlIdentifiers as U, ValueType as V, WidthType as W, DecorationType as X, FontType as Y, AppType as Z, InitialExpandedItems as _, type AddControlResponse as a, type Money as a$, VerticalAlignment as a0, NullValue as a1, Type as a2, WebhookIdentityType as a3, type InputControl as a4, type Input as a5, type OptionSelection as a6, type OptionSelectionSelectedOptionOneOf as a7, type Label as a8, type FormMessages as a9, type UpdateControlRequest as aA, type UpdateControlRequestControlOneOf as aB, type NameControl as aC, type NameControlLabels as aD, type EmailControl as aE, type DeleteControlRequest as aF, type UpdateMessagesRequest as aG, type PublishDraftRequest as aH, type EventUpdated as aI, type Location as aJ, type MapCoordinates as aK, type Address as aL, type AddressStreetOneOf as aM, type StreetAddress as aN, type AddressLocation as aO, type Subdivision as aP, type ScheduleConfig as aQ, type Recurrences as aR, type Occurrence as aS, type Event as aT, type Scheduling as aU, type Registration as aV, type RsvpCollection as aW, type RsvpCollectionConfig as aX, type Ticketing as aY, type TicketingConfig as aZ, type TaxConfig as a_, type RsvpFormMessages as aa, type PositiveResponseConfirmation as ab, type NegativeResponseConfirmation as ac, type Positive as ad, type Negative as ae, type CheckoutFormMessages as af, type ResponseConfirmation as ag, type RegistrationClosedMessages as ah, type TicketsUnavailableMessages as ai, type FormInputControlAdded as aj, type FormInputControlUpdated as ak, type FormInputControlDeleted as al, type GetFormRequest as am, type GetFormResponse as an, type AddControlRequest as ao, type AddControlRequestControlOneOf as ap, type PhoneControl as aq, type AddressControl as ar, type AddressControlLabels as as, type DateControl as at, type AdditionalGuestsControl as au, type Labels as av, type DropdownControl as aw, type RadioButtonControl as ax, type CheckboxControl as ay, type TextControl as az, type UpdateControlOptions as b, type LinkPreviewDataStyles as b$, type ExternalEvent as b0, type CalendarLinks as b1, type SiteUrl as b2, type Dashboard as b3, type RsvpSummary as b4, type TicketingSummary as b5, type GuestListConfig as b6, type Feed as b7, type OnlineConferencing as b8, type OnlineConferencingConfig as b9, type Rel as bA, type CodeBlockData as bB, type TextStyle as bC, type DividerData as bD, type FileData as bE, type FileSource as bF, type FileSourceDataOneOf as bG, type PDFSettings as bH, type GalleryData as bI, type Media as bJ, type Image as bK, type Video as bL, type Item as bM, type ItemDataOneOf as bN, type GalleryOptions as bO, type Layout as bP, type ItemStyle as bQ, type Thumbnails as bR, type GIFData as bS, type GIF as bT, type HeadingData as bU, type HTMLData as bV, type HTMLDataDataOneOf as bW, type ImageData as bX, type StylesBorder as bY, type ImageDataStyles as bZ, type LinkPreviewData as b_, type OnlineConferencingSession as ba, type SeoSettings as bb, type SeoSchema as bc, type Keyword as bd, type Tag as be, type Settings as bf, type Agenda as bg, type Category as bh, type CategoryCounts as bi, type EventDisplaySettings as bj, type LabellingSettings as bk, type RichContent as bl, type Node as bm, type NodeDataOneOf as bn, type NodeStyle as bo, type ButtonData as bp, type Border as bq, type Colors as br, type PluginContainerData as bs, type PluginContainerDataWidth as bt, type PluginContainerDataWidthDataOneOf as bu, type Spoiler as bv, type Height as bw, type Styles as bx, type Link as by, type LinkDataOneOf as bz, type UpdateControlResponse as c, type BaseEventMetadata as c$, type MapData as c0, type MapSettings as c1, type ParagraphData as c2, type PollData as c3, type Permissions as c4, type Option as c5, type PollSettings as c6, type PollLayout as c7, type OptionLayout as c8, type Gradient as c9, type Dimensions as cA, type TableCellData as cB, type CellStyle as cC, type BorderColors as cD, type ListValue as cE, type AudioData as cF, type OrderedListData as cG, type BulletedListData as cH, type BlockquoteData as cI, type CaptionData as cJ, type LayoutCellData as cK, type Metadata as cL, type DocumentStyle as cM, type TextNodeStyle as cN, type Badge as cO, type DiscardDraftRequest as cP, type DiscardDraftResponse as cQ, type DomainEvent as cR, type DomainEventBodyOneOf as cS, type EntityCreatedEvent as cT, type RestoreInfo as cU, type EntityUpdatedEvent as cV, type EntityDeletedEvent as cW, type ActionEvent as cX, type MessageEnvelope as cY, type IdentificationData as cZ, type IdentificationDataIdOneOf as c_, type Background as ca, type BackgroundBackgroundOneOf as cb, type PollDesign as cc, type OptionDesign as cd, type Poll as ce, type PollDataLayout as cf, type Design as cg, type TextData as ch, type Decoration as ci, type DecorationDataOneOf as cj, type AnchorData as ck, type ColorData as cl, type LinkData as cm, type MentionData as cn, type FontSizeData as co, type SpoilerData as cp, type AppEmbedData as cq, type AppEmbedDataAppDataOneOf as cr, type BookingData as cs, type EventData as ct, type VideoData as cu, type PlaybackOptions as cv, type EmbedData as cw, type Oembed as cx, type CollapsibleListData as cy, type TableData as cz, type DeleteControlResponse as d, type AddControlOptionsControlOneOf as d0, type UpdateControlIdentifiersControlOneOf as d1, type UpdateControlOptionsControlOneOf as d2, type UpdateMessagesOptions as e, type UpdateMessagesResponse as f, type FormEventUpdatedEnvelope as g, Status as h, EventType as i, RegistrationStatus as j, RsvpStatusOptions as k, VisitorType as l, State as m, PluginContainerDataAlignment as n, Target as o, TextAlignment as p, LineStyle as q, Width as r, Alignment as s, ViewMode as t, LayoutType as u, Crop as v, ThumbnailsAlignment as w, Source as x, Position as y, ViewRole as z };
