import { am as GetFormRequest$1, an as GetFormResponse$1, ao as AddControlRequest$1, a as AddControlResponse$1, aA as UpdateControlRequest$1, c as UpdateControlResponse$1, aF as DeleteControlRequest$1, d as DeleteControlResponse$1, aG as UpdateMessagesRequest$1, f as UpdateMessagesResponse$1, aH as PublishDraftRequest$1, P as PublishDraftResponse$1, cP as DiscardDraftRequest$1, cQ as DiscardDraftResponse$1 } from './events-v1-form-forms.universal-Dmp4nCQH.js';

/**
 * The form defines which elements are displayed to a site visitor during the registration process (RSVP or checkout).
 * It also contains customizable messages and labels.
 *
 *
 * A form is an ordered list of controls (blocks), which accept guest information into a field input.
 *
 * Each control contains one or more nested inputs. For example, `Name` control has two inputs:
 * - First Name
 * - Last Name
 *
 * By default, name and email controls are always required and are pinned to the top of the form.
 */
interface Form {
    /** Nested fields as an ordered list. */
    controls?: InputControl[];
    /**
     * Set of defined form messages displayed in the UI before, during, and after a registration flow.
     * Includes the configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
     */
    messages?: FormMessages;
}
/**
 * A block of nested fields.
 * Used to aggregate similar inputs like First Name and Last Name.
 */
interface InputControl {
    /** Field control type. */
    type?: InputControlTypeWithLiterals;
    /** Whether the control is mandatory (such as `name` & `email`). When `true`, only the label can be changed. */
    system?: boolean;
    /**
     * Deprecated: Use `id` or `_id`.
     * @deprecated
     */
    name?: string;
    /** Child inputs. */
    inputs?: Input[];
    /**
     * *Deprecated:** Use `controls.inputs.label`.
     * @deprecated
     */
    label?: string;
    /** Field controls are sorted by this value in ascending order. */
    orderIndex?: number;
    /** Unique control ID. */
    id?: string;
    /**
     * Whether the input control is deleted.
     * @readonly
     */
    deleted?: boolean | null;
}
declare enum InputControlType {
    /** Single text value field. */
    INPUT = "INPUT",
    /** Single text value field with multiple lines. */
    TEXTAREA = "TEXTAREA",
    /** Single-choice field with predefined values. */
    DROPDOWN = "DROPDOWN",
    /** Single-choice field with predefined values. */
    RADIO = "RADIO",
    /** Multiple-choice field with predefined values. */
    CHECKBOX = "CHECKBOX",
    /** Fields for entering first and last names. */
    NAME = "NAME",
    /** Fields for additional guests and their respective names. */
    GUEST_CONTROL = "GUEST_CONTROL",
    /** Single-line address field. */
    ADDRESS_SHORT = "ADDRESS_SHORT",
    /** Full address field with multiple lines. */
    ADDRESS_FULL = "ADDRESS_FULL",
    /** Fields for entering year, month, and day. */
    DATE = "DATE"
}
/** @enumType */
type InputControlTypeWithLiterals = InputControlType | 'INPUT' | 'TEXTAREA' | 'DROPDOWN' | 'RADIO' | 'CHECKBOX' | 'NAME' | 'GUEST_CONTROL' | 'ADDRESS_SHORT' | 'ADDRESS_FULL' | 'DATE';
/** Child inputs. */
interface Input {
    /** Field name. */
    name?: string;
    /**
     * *Deprecated:** Use `controls.inputs.type.TEXT_ARRAY`.
     * @deprecated
     */
    array?: boolean;
    /** Main field label. */
    label?: string;
    /** Additional labels for multi-valued fields such as address. */
    additionalLabels?: Record<string, string>;
    /** Predefined choice options for fields, such as dropdown. */
    options?: string[];
    /** Whether field is mandatory. */
    mandatory?: boolean;
    /** Maximum number of accepted characters (relevant for text fields). */
    maxLength?: number;
    /**
     * Type which determines field format.
     * Used to validate submitted response.
     */
    type?: ValueTypeWithLiterals;
    /**
     * The maximum number of accepted values for array input.
     *
     * **Note:** Only applicable for `TEXT_ARRAY` input fields.
     */
    maxSize?: number | null;
    /**
     * Default option initially selected when an input has multiple choices.
     *
     * Defaults to first (0th) option, if not configured.
     * Currently only applicable for `type.dropdown`.
     */
    defaultOptionSelection?: OptionSelection;
    /**
     * Additional labels for multi-valued fields, such as address.
     * @readonly
     */
    labels?: Label[];
}
declare enum ValueType {
    TEXT = "TEXT",
    NUMBER = "NUMBER",
    TEXT_ARRAY = "TEXT_ARRAY",
    DATE_TIME = "DATE_TIME",
    ADDRESS = "ADDRESS"
}
/** @enumType */
type ValueTypeWithLiterals = ValueType | 'TEXT' | 'NUMBER' | 'TEXT_ARRAY' | 'DATE_TIME' | 'ADDRESS';
/**
 * Describes initially selected option when an input has multiple choices.
 * Defaults to first (0th) option if not configured.
 */
interface OptionSelection extends OptionSelectionSelectedOptionOneOf {
    /**
     * 0-based index from predefined `controls.inputs.options` which is initial selection.
     * @max 199
     */
    optionIndex?: number;
    /**
     * Placeholder hint describing expected choices, such as "Please select".
     * Considered an empty choice.
     * @maxLength 200
     */
    placeholderText?: string;
}
/** @oneof */
interface OptionSelectionSelectedOptionOneOf {
    /**
     * 0-based index from predefined `controls.inputs.options` which is initial selection.
     * @max 199
     */
    optionIndex?: number;
    /**
     * Placeholder hint describing expected choices, such as "Please select".
     * Considered an empty choice.
     * @maxLength 200
     */
    placeholderText?: string;
}
interface Label {
    /** Field name. */
    name?: string;
    /** Field label. */
    label?: string;
}
/**
 * Defines form messages shown in UI before, during, and after registration flow.
 * It enables configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
 */
interface FormMessages {
    /** RSVP form ([SDK](https://dev.wix.com/docs/sdk/backend-modules/events/rsvp-v2/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/events/rsvp-v2/introduction)) messages. */
    rsvp?: RsvpFormMessages;
    /** Checkout form messages. */
    checkout?: CheckoutFormMessages;
    /** Messages shown when event registration is closed. */
    registrationClosed?: RegistrationClosedMessages;
    /** Messages shown when event tickets are unavailable. */
    ticketsUnavailable?: TicketsUnavailableMessages;
}
interface RsvpFormMessages {
    /** Label text indicating RSVP's `status` is `"YES"`. */
    rsvpYesOption?: string;
    /** Label text indicating RSVP's `status` is `"NO"`. */
    rsvpNoOption?: string;
    /** Messages displayed when an RSVP's `status` is set to `"YES"`. */
    positiveMessages?: Positive;
    /** Messages displayed when an RSVP's `status` is set to `"WAITLIST"`, for when the event is full and a waitlist is available). */
    waitlistMessages?: Positive;
    /** Messages displayed when an RSVP's `status` is set to `"NO"`. */
    negativeMessages?: Negative;
    /** "Submit form" call-to-action label text. */
    submitActionLabel?: string;
}
/** Confirmation messages shown after registration. */
interface PositiveResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** Confirmation message text. */
    message?: string;
    /** "Add to calendar" call-to-action label text. */
    addToCalendarActionLabel?: string;
    /** "Share event" call-to-action label text. */
    shareActionLabel?: string;
}
/** Confirmation messages shown after registration. */
interface NegativeResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** "Share event" call-to-action label text. */
    shareActionLabel?: string;
}
/** Set of messages shown during registration when RSVP response is positive. */
interface Positive {
    /** Main form title for positive response. */
    title?: string;
    /** Confirmation messages shown after registration. */
    confirmation?: PositiveResponseConfirmation;
}
/** A set of messages shown during registration with negative response */
interface Negative {
    /** Main form title for negative response. */
    title?: string;
    /** Confirmation messages shown after registration. */
    confirmation?: NegativeResponseConfirmation;
}
interface CheckoutFormMessages {
    /** Main form title for response. */
    title?: string;
    /** Submit form call-to-action label text. */
    submitActionLabel?: string;
    /** Confirmation messages shown after checkout. */
    confirmation?: ResponseConfirmation;
}
/** Confirmation messages shown after checkout. */
interface ResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** Confirmation message text. */
    message?: string;
    /** "Download tickets" call-to-action label text. */
    downloadTicketsLabel?: string;
    /** "Add to calendar" call-to-action label text. */
    addToCalendarLabel?: string;
    /** "Share event" call-to-action label text. */
    shareEventLabel?: string;
}
interface RegistrationClosedMessages {
    /** Message shown when event registration is closed. */
    message?: string;
    /** "Explore other events" call-to-action label text. */
    exploreEventsActionLabel?: string;
}
interface TicketsUnavailableMessages {
    /** Message shown when event tickets are unavailable. */
    message?: string;
    /** "Explore other events" call-to-action label text. */
    exploreEventsActionLabel?: string;
}
interface GetFormRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
interface GetFormResponse {
    /**
     * Currently published event form.
     * Published form is visible to site visitors.
     */
    form?: Form;
    /**
     * Draft event form.
     * Not available to visitors unless published.
     */
    draftForm?: Form;
}
interface AddControlRequest extends AddControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Single-choice radio button style input control. */
    radioButton?: RadioButtonControl;
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
/** @oneof */
interface AddControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Single-choice radio button style input control. */
    radioButton?: RadioButtonControl;
}
interface PhoneControl {
    /**
     * Phone input label.
     * @maxLength 100
     */
    label?: string;
    /** Whether the phone input is required. */
    mandatory?: boolean;
}
interface AddressControl {
    /** Address control labels for each input. */
    labels?: AddressControlLabels;
    /** Whether an address is multi-line (consisting of multiple fields such as country, city, postal code). When `false`, address is single-line. */
    full?: boolean;
    /** Whether the address input is required. */
    mandatory?: boolean;
}
interface AddressControlLabels {
    /**
     * Single-line address input label.
     * @maxLength 100
     */
    addressLine?: string;
    /**
     * Country input label.
     * @maxLength 100
     */
    country?: string;
    /**
     * Subdivision input label.
     * @maxLength 100
     */
    subdivision?: string;
    /**
     * City input label.
     * @maxLength 100
     */
    city?: string;
    /**
     * Postal code input label.
     * @maxLength 100
     */
    postalCode?: string;
    /**
     * Street address input label.
     * @maxLength 100
     */
    streetAddress?: string;
}
interface DateControl {
    /**
     * Input control label.
     * @maxLength 100
     */
    label?: string;
    /** Whether the date input is required. */
    mandatory?: boolean;
}
interface AdditionalGuestsControl {
    /** Additional guests control labels for each input. */
    labels?: Labels;
    /** Whether the individual guest names are required. */
    namesMandatory?: boolean;
    /**
     * Maximum number of additional guests.
     * @min 1
     * @max 10
     */
    maxGuests?: number;
}
interface Labels {
    /**
     * Input label for a single guest.
     * @maxLength 200
     */
    single?: string;
    /**
     * Input label for multiple guests.
     * @maxLength 200
     */
    multiple?: string;
}
interface DropdownControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /**
     * Predefined options guests can choose from.
     * @minSize 2
     * @maxSize 200
     * @maxLength 200
     */
    options?: string[];
    /** Whether a choice is required. */
    mandatory?: boolean;
    /**
     * Default option initially selected when an input has multiple choices.
     *
     * Defaults to first (0th) option, if not configured.
     */
    defaultOptionSelection?: OptionSelection;
}
interface RadioButtonControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /**
     * Predefined options guests can choose from.
     * @minSize 2
     * @maxSize 200
     * @maxLength 200
     */
    options?: string[];
}
interface CheckboxControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /** Whether at least one checkbox is required. */
    mandatory?: boolean;
    /**
     * Predefined options guests can choose from.
     * @minSize 1
     * @maxSize 200
     * @maxLength 200
     */
    options?: string[];
}
interface TextControl {
    /**
     * Input control label.
     * @maxLength 200
     */
    label?: string;
    /** Whether a text input is required. */
    mandatory?: boolean;
    /**
     * Maximum number of characters allowed.
     * @max 1000
     */
    maxLength?: number;
    /** Whether the input control should allow multiple lines in text. */
    multiLine?: boolean;
    /** Whether the input control should be displayed as a comment. */
    comment?: boolean;
}
interface AddControlResponse {
    /** Generated unique input control ID. */
    id?: string;
    /** Modified draft event form. */
    form?: Form;
}
interface UpdateControlRequest extends UpdateControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Main guest name input control. */
    name?: NameControl;
    /** Main guest email input control. */
    email?: EmailControl;
    /** Single-choice radio style input control. */
    radioButton?: RadioButtonControl;
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /** Unique input control ID. */
    id: string;
    /** Index used to sort input controls in ascending order. */
    orderIndex?: number;
}
/** @oneof */
interface UpdateControlRequestControlOneOf {
    /** Phone number input control. */
    phone?: PhoneControl;
    /** Single-line or full address input control. */
    address?: AddressControl;
    /** Day, month, year date input control. */
    date?: DateControl;
    /** Additional guests input control. */
    additionalGuests?: AdditionalGuestsControl;
    /** Single-choice dropdown style input control. */
    dropdown?: DropdownControl;
    /** Multiple-choice checkbox style input control. */
    checkbox?: CheckboxControl;
    /** Free-form text input control. */
    text?: TextControl;
    /** Main guest name input control. */
    name?: NameControl;
    /** Main guest email input control. */
    email?: EmailControl;
    /** Single-choice radio style input control. */
    radioButton?: RadioButtonControl;
}
interface NameControl {
    /** Name control labels of each input. */
    labels?: NameControlLabels;
}
interface NameControlLabels {
    /**
     * First name input label.
     * @maxLength 100
     */
    firstName?: string;
    /**
     * Last name input label .
     * @maxLength 100
     */
    lastName?: string;
}
interface EmailControl {
    /**
     * Email input label.
     * @maxLength 100
     */
    label?: string;
}
interface UpdateControlResponse {
    /** Modified draft event form. */
    form?: Form;
}
interface DeleteControlRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * Unique input control ID.
     * @maxLength 100
     */
    id: string;
}
interface DeleteControlResponse {
    /** Modified draft event form */
    form?: Form;
}
interface UpdateMessagesRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * Set of field paths, specifying which parts of this resource to update.
     * When fields are empty, request is interpreted as full update.
     * Behavior follows [google.protobuf.FieldMask](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask) semantics.
     */
    fields?: string[];
    /** Set of configured form messages to update. */
    messages?: FormMessages;
}
interface UpdateMessagesResponse {
    /** Modified draft event form. */
    form?: Form;
}
interface PublishDraftRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
interface PublishDraftResponse {
    /** Published event form. */
    form?: Form;
}
interface DiscardDraftRequest {
    /**
     * Event ID to which the form belongs.
     * @format GUID
     */
    eventId: string;
}
interface DiscardDraftResponse {
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getForm(): __PublicMethodMetaInfo<'GET', {
    eventId: string;
}, GetFormRequest$1, GetFormRequest, GetFormResponse$1, GetFormResponse>;
declare function addControl(): __PublicMethodMetaInfo<'POST', {
    eventId: string;
}, AddControlRequest$1, AddControlRequest, AddControlResponse$1, AddControlResponse>;
declare function updateControl(): __PublicMethodMetaInfo<'PUT', {
    eventId: string;
    id: string;
}, UpdateControlRequest$1, UpdateControlRequest, UpdateControlResponse$1, UpdateControlResponse>;
declare function deleteControl(): __PublicMethodMetaInfo<'DELETE', {
    eventId: string;
    id: string;
}, DeleteControlRequest$1, DeleteControlRequest, DeleteControlResponse$1, DeleteControlResponse>;
declare function updateMessages(): __PublicMethodMetaInfo<'PATCH', {
    eventId: string;
}, UpdateMessagesRequest$1, UpdateMessagesRequest, UpdateMessagesResponse$1, UpdateMessagesResponse>;
declare function publishDraft(): __PublicMethodMetaInfo<'POST', {
    eventId: string;
}, PublishDraftRequest$1, PublishDraftRequest, PublishDraftResponse$1, PublishDraftResponse>;
declare function discardDraft(): __PublicMethodMetaInfo<'DELETE', {
    eventId: string;
}, DiscardDraftRequest$1, DiscardDraftRequest, DiscardDraftResponse$1, DiscardDraftResponse>;

export { type __PublicMethodMetaInfo, addControl, deleteControl, discardDraft, getForm, publishDraft, updateControl, updateMessages };
